=================================
``psyclone.psyir.symbols.symbol``
=================================

.. automodule:: psyclone.psyir.symbols.symbol

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.symbols.symbol
